==> ejc-sale-impl-3.0.0-20220404.055637-20-sources.jar: com/ejianc/business/sale/bean/SalesorderdetilsEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 销售单子表信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_salesorderdetils")
public class SalesorderdetilsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="salesorder_id")
    private Long salesorderId; // 主表主键
    @TableField(value="sort")
    private Long sort; // 序号
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="spec_name")
    private String specName; // 规格
    @TableField(value="unit_price")
    private BigDecimal unitPrice; // 单价
    @TableField(value="sales_volume")
    private Long salesVolume; // 销售数量
    @TableField(value="sales_amount")
    private BigDecimal salesAmount; // 销售金额
    @TableField(value="production_quantity")
    private Long productionQuantity; // 生产数量
    @TableField(value="production_amount")
    private BigDecimal productionAmount; // 生产金额
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="stone_name")
    private String stoneName; // 石料
    @TableField(value="asphalt_name")
    private String asphaltName; // 沥青
    @TableField(value="category_id1")
    private Long categoryId1; // 分类id1
    @TableField(value="category_name1")
    private String categoryName1; // 材料分类名称1
    @TableField(value="varieties_id1")
    private Long varietiesId1; // 品种id1
    @TableField(value="varieties_name1")
    private String varietiesName1; // 品种名称1
    @TableField(value="thousand_rate1")
    private BigDecimal thousandRate1; // 千分比1
    @TableField(value="category_id2")
    private Long categoryId2; // 分类id2
    @TableField(value="category_name2")
    private String categoryName2; // 材料分类名称2
    @TableField(value="varieties_id2")
    private Long varietiesId2; // 品种id2
    @TableField(value="varieties_name2")
    private String varietiesName2; // 品种名称2
    @TableField(value="thousand_rate2")
    private BigDecimal thousandRate2; // 千分比2
    @TableField(value="category_id3")
    private Long categoryId3; // 分类id3
    @TableField(value="category_name3")
    private String categoryName3; // 材料分类名称3
    @TableField(value="varieties_id3")
    private Long varietiesId3; // 品种id3
    @TableField(value="varieties_name3")
    private String varietiesName3; // 品种名称3
    @TableField(value="thousand_rate3")
    private BigDecimal thousandRate3; // 千分比3
    @TableField(value="product_id")
    private Long productId; // 产品id
    
    
    

    public Long getSalesorderId() {
        return salesorderId;
    }

    public void setSalesorderId(Long salesorderId) {
        this.salesorderId = salesorderId;
    }
    public Long getSort() {
        return sort;
    }

    public void setSort(Long sort) {
        this.sort = sort;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public String getSpecName() {
        return specName;
    }

    public void setSpecName(String specName) {
        this.specName = specName;
    }
    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    public Long getSalesVolume() {
        return salesVolume;
    }

    public void setSalesVolume(Long salesVolume) {
        this.salesVolume = salesVolume;
    }
    public BigDecimal getSalesAmount() {
        return salesAmount;
    }

    public void setSalesAmount(BigDecimal salesAmount) {
        this.salesAmount = salesAmount;
    }
    public Long getProductionQuantity() {
        return productionQuantity;
    }

    public void setProductionQuantity(Long productionQuantity) {
        this.productionQuantity = productionQuantity;
    }
    public BigDecimal getProductionAmount() {
        return productionAmount;
    }

    public void setProductionAmount(BigDecimal productionAmount) {
        this.productionAmount = productionAmount;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getStoneName() {
        return stoneName;
    }

    public void setStoneName(String stoneName) {
        this.stoneName = stoneName;
    }
    public String getAsphaltName() {
        return asphaltName;
    }

    public void setAsphaltName(String asphaltName) {
        this.asphaltName = asphaltName;
    }
    public Long getCategoryId1() {
        return categoryId1;
    }

    public void setCategoryId1(Long categoryId1) {
        this.categoryId1 = categoryId1;
    }
    public String getCategoryName1() {
        return categoryName1;
    }

    public void setCategoryName1(String categoryName1) {
        this.categoryName1 = categoryName1;
    }
    public Long getVarietiesId1() {
        return varietiesId1;
    }

    public void setVarietiesId1(Long varietiesId1) {
        this.varietiesId1 = varietiesId1;
    }
    public String getVarietiesName1() {
        return varietiesName1;
    }

    public void setVarietiesName1(String varietiesName1) {
        this.varietiesName1 = varietiesName1;
    }
    public BigDecimal getThousandRate1() {
        return thousandRate1;
    }

    public void setThousandRate1(BigDecimal thousandRate1) {
        this.thousandRate1 = thousandRate1;
    }
    public Long getCategoryId2() {
        return categoryId2;
    }

    public void setCategoryId2(Long categoryId2) {
        this.categoryId2 = categoryId2;
    }
    public String getCategoryName2() {
        return categoryName2;
    }

    public void setCategoryName2(String categoryName2) {
        this.categoryName2 = categoryName2;
    }
    public Long getVarietiesId2() {
        return varietiesId2;
    }

    public void setVarietiesId2(Long varietiesId2) {
        this.varietiesId2 = varietiesId2;
    }
    public String getVarietiesName2() {
        return varietiesName2;
    }

    public void setVarietiesName2(String varietiesName2) {
        this.varietiesName2 = varietiesName2;
    }
    public BigDecimal getThousandRate2() {
        return thousandRate2;
    }

    public void setThousandRate2(BigDecimal thousandRate2) {
        this.thousandRate2 = thousandRate2;
    }
    public Long getCategoryId3() {
        return categoryId3;
    }

    public void setCategoryId3(Long categoryId3) {
        this.categoryId3 = categoryId3;
    }
    public String getCategoryName3() {
        return categoryName3;
    }

    public void setCategoryName3(String categoryName3) {
        this.categoryName3 = categoryName3;
    }
    public Long getVarietiesId3() {
        return varietiesId3;
    }

    public void setVarietiesId3(Long varietiesId3) {
        this.varietiesId3 = varietiesId3;
    }
    public String getVarietiesName3() {
        return varietiesName3;
    }

    public void setVarietiesName3(String varietiesName3) {
        this.varietiesName3 = varietiesName3;
    }
    public BigDecimal getThousandRate3() {
        return thousandRate3;
    }

    public void setThousandRate3(BigDecimal thousandRate3) {
        this.thousandRate3 = thousandRate3;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    
}

==> ejc-sale-impl-3.0.0-20220419.090228-47-sources.jar: com/ejianc/business/sale/bean/SalesorderdetilsEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 销售单子表信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_salesorderdetils")
public class SalesorderdetilsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="salesorder_id")
    private Long salesorderId; // 主表主键
    @TableField(value="sort")
    private Long sort; // 序号
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="spec_name")
    private String specName; // 规格
    @TableField(value="unit_price")
    private BigDecimal unitPrice; // 单价
    @TableField(value="sales_volume")
    private BigDecimal salesVolume; // 销售数量
    @TableField(value="sales_amount")
    private BigDecimal salesAmount; // 销售金额
    @TableField(value="production_quantity")
    private BigDecimal productionQuantity; // 生产数量
    @TableField(value="production_amount")
    private BigDecimal productionAmount; // 生产金额
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="stone_name")
    private String stoneName; // 石料
    @TableField(value="asphalt_name")
    private String asphaltName; // 沥青
    @TableField(value="category_id1")
    private Long categoryId1; // 分类id1
    @TableField(value="category_name1")
    private String categoryName1; // 材料分类名称1
    @TableField(value="varieties_id1")
    private Long varietiesId1; // 品种id1
    @TableField(value="varieties_name1")
    private String varietiesName1; // 品种名称1
    @TableField(value="thousand_rate1")
    private BigDecimal thousandRate1; // 千分比1
    @TableField(value="category_id2")
    private Long categoryId2; // 分类id2
    @TableField(value="category_name2")
    private String categoryName2; // 材料分类名称2
    @TableField(value="varieties_id2")
    private Long varietiesId2; // 品种id2
    @TableField(value="varieties_name2")
    private String varietiesName2; // 品种名称2
    @TableField(value="thousand_rate2")
    private BigDecimal thousandRate2; // 千分比2
    @TableField(value="category_id3")
    private Long categoryId3; // 分类id3
    @TableField(value="category_name3")
    private String categoryName3; // 材料分类名称3
    @TableField(value="varieties_id3")
    private Long varietiesId3; // 品种id3
    @TableField(value="varieties_name3")
    private String varietiesName3; // 品种名称3
    @TableField(value="thousand_rate3")
    private BigDecimal thousandRate3; // 千分比3
    @TableField(value="product_id")
    private Long productId; // 产品id
    
    
    

    public Long getSalesorderId() {
        return salesorderId;
    }

    public void setSalesorderId(Long salesorderId) {
        this.salesorderId = salesorderId;
    }
    public Long getSort() {
        return sort;
    }

    public void setSort(Long sort) {
        this.sort = sort;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public String getSpecName() {
        return specName;
    }

    public void setSpecName(String specName) {
        this.specName = specName;
    }
    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    public BigDecimal getSalesVolume() {
        return salesVolume;
    }

    public void setSalesVolume(BigDecimal salesVolume) {
        this.salesVolume = salesVolume;
    }
    public BigDecimal getSalesAmount() {
        return salesAmount;
    }

    public void setSalesAmount(BigDecimal salesAmount) {
        this.salesAmount = salesAmount;
    }
    public BigDecimal getProductionQuantity() {
        return productionQuantity;
    }

    public void setProductionQuantity(BigDecimal productionQuantity) {
        this.productionQuantity = productionQuantity;
    }
    public BigDecimal getProductionAmount() {
        return productionAmount;
    }

    public void setProductionAmount(BigDecimal productionAmount) {
        this.productionAmount = productionAmount;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getStoneName() {
        return stoneName;
    }

    public void setStoneName(String stoneName) {
        this.stoneName = stoneName;
    }
    public String getAsphaltName() {
        return asphaltName;
    }

    public void setAsphaltName(String asphaltName) {
        this.asphaltName = asphaltName;
    }
    public Long getCategoryId1() {
        return categoryId1;
    }

    public void setCategoryId1(Long categoryId1) {
        this.categoryId1 = categoryId1;
    }
    public String getCategoryName1() {
        return categoryName1;
    }

    public void setCategoryName1(String categoryName1) {
        this.categoryName1 = categoryName1;
    }
    public Long getVarietiesId1() {
        return varietiesId1;
    }

    public void setVarietiesId1(Long varietiesId1) {
        this.varietiesId1 = varietiesId1;
    }
    public String getVarietiesName1() {
        return varietiesName1;
    }

    public void setVarietiesName1(String varietiesName1) {
        this.varietiesName1 = varietiesName1;
    }
    public BigDecimal getThousandRate1() {
        return thousandRate1;
    }

    public void setThousandRate1(BigDecimal thousandRate1) {
        this.thousandRate1 = thousandRate1;
    }
    public Long getCategoryId2() {
        return categoryId2;
    }

    public void setCategoryId2(Long categoryId2) {
        this.categoryId2 = categoryId2;
    }
    public String getCategoryName2() {
        return categoryName2;
    }

    public void setCategoryName2(String categoryName2) {
        this.categoryName2 = categoryName2;
    }
    public Long getVarietiesId2() {
        return varietiesId2;
    }

    public void setVarietiesId2(Long varietiesId2) {
        this.varietiesId2 = varietiesId2;
    }
    public String getVarietiesName2() {
        return varietiesName2;
    }

    public void setVarietiesName2(String varietiesName2) {
        this.varietiesName2 = varietiesName2;
    }
    public BigDecimal getThousandRate2() {
        return thousandRate2;
    }

    public void setThousandRate2(BigDecimal thousandRate2) {
        this.thousandRate2 = thousandRate2;
    }
    public Long getCategoryId3() {
        return categoryId3;
    }

    public void setCategoryId3(Long categoryId3) {
        this.categoryId3 = categoryId3;
    }
    public String getCategoryName3() {
        return categoryName3;
    }

    public void setCategoryName3(String categoryName3) {
        this.categoryName3 = categoryName3;
    }
    public Long getVarietiesId3() {
        return varietiesId3;
    }

    public void setVarietiesId3(Long varietiesId3) {
        this.varietiesId3 = varietiesId3;
    }
    public String getVarietiesName3() {
        return varietiesName3;
    }

    public void setVarietiesName3(String varietiesName3) {
        this.varietiesName3 = varietiesName3;
    }
    public BigDecimal getThousandRate3() {
        return thousandRate3;
    }

    public void setThousandRate3(BigDecimal thousandRate3) {
        this.thousandRate3 = thousandRate3;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    
}
